<?php
#
# PDFlib PLOP DS:
# Encrypt file with certificate security.
#

$recipients = array(
    /* no permission restrictions */
    array( "cert"=>"../data/demo_recipient_1.pem", "perm"=>"" ),

    /* form filling and signing permissions granted, but not others */
    array( "cert"=>"../data/demo_recipient_2.pem", "perm"=>"nomodify nocopy noannots noassemble" ),
    array( "cert"=>"../data/demo_recipient_3.pem", "perm"=>"nomodify nocopy noannots noassemble" ),
);

# This is where input files live. Adjust as necessary.
$searchpath = "../data ../../data";

try {
    # create a new PLOP object
    $plop = new PLOP();

    $infile = "PLOP-datasheet.pdf";
    $outfile = "";
    $optlist;

    $optlist = sprintf("searchpath={%s}", $searchpath);
    $plop->set_option($optlist);

    /* open unprotected input file */
    if (($doc = $plop->open_document($infile, "")) == 0)
    {
        die("Error: " . $plop->get_errmsg() . "\n");
    }

    /* add recipients */
    for ($r = 0; $r < count($recipients); $r++)
    {
        $optlist = sprintf("certificate={filename={%s}} permissions={%s}",
            $recipients[$r]{"cert"}, $recipients[$r]{"perm"});
        if ($plop->add_recipient($optlist) == -1) {
            /* emit warning and continue */
            printf("Error: " . $plop->get_errmsg() . "\n");
        }
    }

    #* create protected output file */
    $optlist = sprintf("input=%d", $doc);
    if ($plop->create_document($outfile, $optlist) == 0)
    {
        die("Error: " . $plop->get_errmsg() . "\n");
    }

    $buf = $plop->get_buffer();
    $len = strlen($buf);

    header("Content-type: application/pdf");
    header("Content-Length: $len");
    header("Content-Disposition: inline; filename=certsec.pdf");
    print $buf;

    $plop->close_document($doc, "");
}
catch (PLOPException $e) {
    die("PLOP exception occurred in certsec sample:\n" .
        "[" . $e->get_errnum() . "] " . $e->get_apiname() . ": " .
        $e->get_errmsg() . "\n");
    }
catch (Exception $e) {
    die($e);
}

$plop = 0;
